********************************
Contributing code to fortnet-ase
********************************

fortnet-ase is an open source project, and everyone is welcome to contribute
improvements and extensions, provided they are willing to provide their
changes under the same license as fortnet-ase itself (BSD-2-Clause).


How to contribute
=================

The preferred method is to fork the project on `github
<https://github.com/vanderhe/fortnet-ase/>`_), make your changes and then create
a pull request. Your changes should be based on the default branch.


Attribution
===========

Every contributor is welcome to be listed in the `AUTHORS.rst` file. List
yourself by including a change to `AUTHORS.rst` in your pull
request. Contributors should be ordered alphabetically by their family name.


Developer certificate of origin
===============================

When you contribute to the project, your contribution must align with the
`Developer Certificate of Origin
<https://developercertificate.org/>`_::

    Developer Certificate of Origin
    Version 1.1
    
    Copyright (C) 2004, 2006 The Linux Foundation and its contributors.
    1 Letterman Drive
    Suite D4700
    San Francisco, CA, 94129
    
    Everyone is permitted to copy and distribute verbatim copies of this
    license document, but changing it is not allowed.
    
    
    Developer's Certificate of Origin 1.1
    
    By making a contribution to this project, I certify that:
    
    (a) The contribution was created in whole or in part by me and I
        have the right to submit it under the open source license
        indicated in the file; or
    
    (b) The contribution is based upon previous work that, to the best
        of my knowledge, is covered under an appropriate open source
        license and I have the right under that license to submit that
        work with modifications, whether created in whole or in part
        by me, under the same open source license (unless I am
        permitted to submit under a different license), as indicated
        in the file; or
    
    (c) The contribution was provided directly to me by some other
        person who certified (a), (b) or (c) and I have not modified
        it.
    
    (d) I understand and agree that this project and the contribution
        are public and that a record of the contribution (including all
        personal information I submit with it, including my sign-off) is
        maintained indefinitely and may be redistributed consistent with
        this project or the open source license(s) involved.


By issuing a pull request or contributing code in any other ways to the project,
you explicitly declare that your contribution is in accordance with the
Developer's Certificate of Origin as described above.

Please, also make sure, that all of your git commits contain your real name and
email address; pseudonyms and anonymous contributions unfortunately can not be
accepted.
